@@ -170,7 +170,10 @@ class PenStyleWindow(QtWidgets.QDialog):
         parent.canvas.penColor = self.penColor
         parent.canvas.penThickness = self.penThickness 
         parent.canvas.penStyle = self.penStyle
-        
+        with open(osp.join(osp.dirname(osp.realpath(__file__)), 'widgets/crossSave.txt'), 'w', encoding='utf-8') as f:
+            f.write(str(self.penStyle)+'\n')
+            f.write(str(self.penThickness)+'\n')
+            f.write(str(self.penColor)+'\n')    
         
 class MainWindow(QtWidgets.QMainWindow):
 
@@ -231,15 +234,18 @@ class MainWindow(QtWidgets.QMainWindow):
         self.flag_dock.setWidget(self.flag_widget)
         self.flag_widget.itemChanged.connect(self.setDirty)
 
+
+
+
         #self.labelList.itemActivated.connect(self.labelSelectionChanged)
         self.labelList.itemSelectionChanged.connect(self.labelSelectionChanged)
         self.labelList.itemDoubleClicked.connect(self.editLabel)
         # Connect to itemChanged to detect checkbox changes.
         self.labelList.itemChanged.connect(self.labelItemChanged)
         self.labelList.itemDropped.connect(self.labelOrderChanged)
-        #self.labelList.setDragDropMode(
-        #    QtWidgets.QAbstractItemView.InternalMove)
-        #self.labelList.setParent(self)
+        self.labelList.setDragDropMode(
+           QtWidgets.QAbstractItemView.InternalMove)
+        self.labelList.setParent(self)
         self.shape_dock = QtWidgets.QDockWidget(
             self.tr('Polygon Labels'),
             self
@@ -247,6 +253,9 @@ class MainWindow(QtWidgets.QMainWindow):
         self.shape_dock.setObjectName('Labels')
         self.shape_dock.setWidget(self.labelList)
 
+
+
+
         self.uniqLabelList = UniqueLabelQListWidget()
         self.uniqLabelList.setToolTip(self.tr(
             "Select label to start annotating for it. "
@@ -491,11 +500,17 @@ class MainWindow(QtWidgets.QMainWindow):
                       enabled=False)
 
         showAll = action(self.tr('&Hide/Show\nPolygons'),
-                         self.togglePolygons,
-                         shortcuts['show_polygon'],
+                         functools.partial(self.togglePolygons, 0, False),
+                         shortcuts['show_polygon'], checkable=True,
                          icon='eye', tip=self.tr('Show all polygons'),
-                         enabled=False)
+                         enabled=True)
 
+        hideOthers = action(self.tr('&Immersive mode'),
+                            self.immersiveMode,
+                            icon='focus', tip=self.tr('Hide other polygons when creating polygon'),
+                            checkable=True, checked=self._config['hide_others'])
+        hideOthers.setChecked(self._config['hide_others'])
+        
         help = action(self.tr('&About'), self.about, icon='help',
                       tip=self.tr('About EnhancedLabelMe'))
         
@@ -558,9 +573,9 @@ class MainWindow(QtWidgets.QMainWindow):
                            tip=self.tr('Show cross hair around the mouse cursor'),
                            checkable=True, checked=self._config['cross_hair'],)
         crossHair.setChecked(self._config['cross_hair'])
-        crossStyle = action(self.tr('&Cross-line Style'), self.crossStyleSetting,
+        crossStyle = action(self.tr('&Customize Cross-line Style'), self.crossStyleSetting,
                              icon='edit', tip=self.tr(u'Configure Cross-line Style'))
-        
+
         darkMode = action(self.tr('&Dark Theme'), self.darkModeToggle, icon='dark',
                 tip=self.tr('Toggle dark theme'), checkable=True, checked=self._config['dark_mode'],)
 
@@ -632,6 +647,8 @@ class MainWindow(QtWidgets.QMainWindow):
             crossHair=crossHair,
             crossStyle=crossStyle,
             darkMode=darkMode,
+            hideOthers=hideOthers,
+            showAll=showAll,
             # XXX: need to add some actions here to activate the shortcut
             editMenu=(
                 edit,
@@ -726,6 +743,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 fill_drawing,
                 None,
                 showAll,
+                hideOthers,
                 None,
                 zoomIn,
                 zoomOut,
@@ -1040,6 +1058,14 @@ class MainWindow(QtWidgets.QMainWindow):
             self.canvas.cross = True
         elif self.actions.crossHair.isChecked() == False:
             self.canvas.cross = False
+            
+    def immersiveMode(self):
+        if self.actions.hideOthers.isChecked() == True:
+            self.polygon = True
+            self.canvas.immersive = True
+        elif self.actions.hideOthers.isChecked() == False:
+            self.polygon = False
+            self.canvas.immersive = False
     
     def toggleDrawingSensitive(self, drawing=True):
         """Toggle drawing sensitive.
@@ -1106,7 +1132,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.actions.createLineStripMode.setEnabled(False)
             else:
                 raise ValueError('Unsupported createMode: %s' % createMode)
-        self.actions.editMode.setEnabled(not edit)
+        self.actions.editMode.setEnabled(not edit)  
 
     def setEditMode(self):
         self.toggleDrawMode(True)
@@ -1468,6 +1494,11 @@ class MainWindow(QtWidgets.QMainWindow):
             self.actions.undoLastPoint.setEnabled(False)
             self.actions.undo.setEnabled(True)
             self.setDirty()
+            # if self.polygon:
+                # self.togglePolygons(1, False)
+            if self.actions.hideOthers.isChecked() == True:
+                self.canvas.keyboard_con()
+                self.canvas.immersive_first = True
         else:
             self.canvas.undoLastLine()
             self.canvas.shapesBackups.pop()
@@ -1556,13 +1587,13 @@ class MainWindow(QtWidgets.QMainWindow):
         contrast = dialog.slider_contrast.value()
         self.brightnessContrast_values[self.filename] = (brightness, contrast)
 
-    def togglePolygons(self):
-        if self.polygon:
-            self.polygon = False
-        else:
-            self.polygon = True
-        for item in self.labelList:
-            item.setCheckState(Qt.Checked if self.polygon else Qt.Unchecked)
+    def togglePolygons(self, mode, value):
+        if mode == 0:
+            for item in self.labelList:
+                item.setCheckState(Qt.Checked if not self.actions.showAll.isChecked() else Qt.Unchecked)
+        elif mode == 1:
+            for item in self.labelList:
+                item.setCheckState(Qt.Checked if not value else Qt.Unchecked)
 
     def loadFile(self, filename=None):
         """Load the specified file, or the last opened file if None."""
