@@ -2,7 +2,10 @@ from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
 
-import sys  
+import os
+import os.path as osp
+import sys 
+import pynput
 
 from enhancedlabelme import QT5
 from enhancedlabelme.shape import Shape
@@ -18,7 +21,6 @@ CURSOR_DRAW = QtCore.Qt.CrossCursor
 CURSOR_MOVE = QtCore.Qt.ClosedHandCursor
 CURSOR_GRAB = QtCore.Qt.OpenHandCursor
 
-
 class Canvas(QtWidgets.QWidget):
 
     zoomRequest = QtCore.Signal(int, QtCore.QPoint)
@@ -87,9 +89,56 @@ class Canvas(QtWidgets.QWidget):
         self.cross = False
         self.posc = None
         self.dialog = False
+        self.firstLoad = False
         self.penStyle = QtCore.Qt.DashLine
         self.penThickness = 1.0
         self.penColor = QtCore.Qt.black
+        self.immersive = False
+        self.immersive_first = True
+        self.keyboard_button = pynput.keyboard.Controller()
+        self.keyboard_key = pynput.keyboard.Key
+
+        fn = str(osp.join(osp.dirname(osp.realpath(__file__)), 'crossSave.txt'))
+        # Load previous cross-line style
+        if osp.isfile(fn) and self.firstLoad == False:
+            with open(fn, 'r', encoding='utf-8') as f:
+                lines = [line.rstrip() for line in f]
+                
+                if lines[0] == str(QtCore.Qt.SolidLine):
+                    self.penStyle = QtCore.Qt.SolidLine
+                elif lines[0] == str(QtCore.Qt.DashLine):
+                    self.penStyle = QtCore.Qt.DashLine
+                elif lines[0] == str(QtCore.Qt.DotLine):
+                    self.penStyle = QtCore.Qt.DotLine
+                
+                self.penThickness = float(lines[1])
+                
+                if lines[2] == str(QtCore.Qt.black):
+                    self.penColor = QtCore.Qt.black
+                elif lines[2] == str(QtCore.Qt.white):
+                    self.penColor = QtCore.Qt.white
+                elif lines[2] == str(QtCore.Qt.gray):
+                    self.penColor = QtCore.Qt.gray
+                elif lines[2] == str(QtCore.Qt.gray):
+                    self.penColor = QtCore.Qt.red
+                elif lines[2] == str(QtCore.Qt.yellow):
+                    self.penColor = QtCore.Qt.yellow
+                elif lines[2] == str(QtCore.Qt.green):
+                    self.penColor = QtCore.Qt.green
+                elif lines[2] == str(QtCore.Qt.blue):
+                    self.penColor = QtCore.Qt.blue
+                elif lines[2] == str(QtCore.Qt.cyan):
+                    self.penColor = QtCore.Qt.cyan
+                elif lines[2] == str(QtCore.Qt.magenta):
+                    self.penColor = QtCore.Qt.magenta
+                    
+                self.firstLoad = True
+        elif self.firstLoad == False:
+            self.penStyle = QtCore.Qt.DashLine
+            self.penThickness = 1.0
+            self.penColor = QtCore.Qt.black
+            self.firstLoad = True
+
 
     def fillDrawing(self):
         return self._fill_drawing
@@ -329,6 +378,9 @@ class Canvas(QtWidgets.QWidget):
             pos = self.transformPos(ev.posF())
         if ev.button() == QtCore.Qt.LeftButton:
             if self.drawing():
+                if self.immersive and self.immersive_first:
+                    self.keyboard_con()
+                    self.immersive_first = False
                 if self.current:
                     # Add point to existing shape.
                     if self.createMode == 'polygon':
@@ -704,6 +756,8 @@ class Canvas(QtWidgets.QWidget):
     def keyPressEvent(self, ev):
         key = ev.key()
         if key == QtCore.Qt.Key_Escape and self.current:
+            self.keyboard_con()
+            self.immersive_first = True
             self.current = None
             self.drawingPolygon.emit(False)
             self.update()
@@ -776,3 +830,9 @@ class Canvas(QtWidgets.QWidget):
         self.pixmap = None
         self.shapesBackups = []
         self.update()
+
+    def keyboard_con(self):
+        self.keyboard_button.press(self.keyboard_key.ctrl)
+        self.keyboard_button.press("2")
+        self.keyboard_button.release(self.keyboard_key.ctrl)
+        self.keyboard_button.release("2")
\ No newline at end of file
